package
Version:
v0.0.0-...-02307e5
Opens a new window with list of versions in this module.
Published: Jun 29, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Orderable interface {
OrderKey() int
}
func (pq *PQ) Pop() interface{}
func (pq *PQ) Push(v interface{})
func (pq PQ) Swap(i, j int)
type Tuple2 struct {
First int
Second int
}
type Tuple3 struct {
First int
Second int
Third int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.